@@ -1,6 +1,6 @@
 /**
  * Logback: the reliable, generic, fast and flexible logging framework.
- * Copyright (C) 1999-2011, QOS.ch. All rights reserved.
+ * Copyright (C) 1999-2013, QOS.ch. All rights reserved.
  *
  * This program and the accompanying materials are dual-licensed under
  * either the terms of the Eclipse Public License v1.0 as published by
@@ -31,8 +31,9 @@ import ch.qos.logback.core.joran.conditional.ElseAction;
 import ch.qos.logback.core.joran.conditional.IfAction;
 import ch.qos.logback.core.joran.conditional.ThenAction;
 import ch.qos.logback.core.joran.spi.DefaultNestedComponentRegistry;
-import ch.qos.logback.core.joran.spi.Pattern;
+import ch.qos.logback.core.joran.spi.ElementSelector;
 import ch.qos.logback.core.joran.spi.RuleStore;
+import ch.qos.logback.core.net.ssl.SSLNestedComponentRegistryRules;
 
 
 
@@ -47,22 +48,22 @@ public class JoranConfigurator extends JoranConfiguratorBase {
   public void addInstanceRules(RuleStore rs) {
     super.addInstanceRules(rs);
     
-    rs.addRule(new Pattern("configuration"), new ConfigurationAction());
-    rs.addRule(new Pattern("configuration/appender-ref"), new AppenderRefAction());
+    rs.addRule(new ElementSelector("configuration"), new ConfigurationAction());
+    rs.addRule(new ElementSelector("configuration/appender-ref"), new AppenderRefAction());
     
-    rs.addRule(new Pattern("configuration/appender/sift"), new SiftAction());
-    rs.addRule(new Pattern("configuration/appender/sift/*"), new NOPAction());
+    rs.addRule(new ElementSelector("configuration/appender/sift"), new SiftAction());
+    rs.addRule(new ElementSelector("configuration/appender/sift/*"), new NOPAction());
     
-    rs.addRule(new Pattern("configuration/evaluator"), new EvaluatorAction());
+    rs.addRule(new ElementSelector("configuration/evaluator"), new EvaluatorAction());
 
     // add if-then-else support
-    rs.addRule(new Pattern("*/if"), new IfAction());
-    rs.addRule(new Pattern("*/if/then"), new ThenAction());
-    rs.addRule(new Pattern("*/if/then/*"), new NOPAction());
-    rs.addRule(new Pattern("*/if/else"), new ElseAction());
-    rs.addRule(new Pattern("*/if/else/*"), new NOPAction());
+    rs.addRule(new ElementSelector("*/if"), new IfAction());
+    rs.addRule(new ElementSelector("*/if/then"), new ThenAction());
+    rs.addRule(new ElementSelector("*/if/then/*"), new NOPAction());
+    rs.addRule(new ElementSelector("*/if/else"), new ElseAction());
+    rs.addRule(new ElementSelector("*/if/else/*"), new NOPAction());
 
-    rs.addRule(new Pattern("configuration/include"), new IncludeAction());
+    rs.addRule(new ElementSelector("configuration/include"), new IncludeAction());
   }
 
   @Override
@@ -74,6 +75,7 @@ public class JoranConfigurator extends JoranConfiguratorBase {
 
     registry.add(AppenderBase.class, "encoder", PatternLayoutEncoder.class);
     registry.add(UnsynchronizedAppenderBase.class, "encoder", PatternLayoutEncoder.class);
+    SSLNestedComponentRegistryRules.addDefaultNestedComponentRegistryRules(registry);
   }
 
 }
