@@ -1,6 +1,6 @@
 /**
  * Logback: the reliable, generic, fast and flexible logging framework.
- * Copyright (C) 1999-2011, QOS.ch. All rights reserved.
+ * Copyright (C) 1999-2013, QOS.ch. All rights reserved.
  *
  * This program and the accompanying materials are dual-licensed under
  * either the terms of the Eclipse Public License v1.0 as published by
@@ -50,7 +50,7 @@ public class SyslogAppender extends SyslogAppenderBase<ILoggingEvent> {
   }
 
   String getPrefixPattern() {
-    return "%syslogStart{" + getFacility() + "}%nopex";
+    return "%syslogStart{" + getFacility() + "}%nopex{}";
   }
 
   /*
@@ -71,13 +71,18 @@ public class SyslogAppender extends SyslogAppenderBase<ILoggingEvent> {
       return;
 
     ILoggingEvent event = (ILoggingEvent) eventObject;
+    IThrowableProxy tp = event.getThrowableProxy();
+
+    if (tp == null)
+      return;
 
     String stackTracePrefix = stackTraceLayout.doLayout(event);
-
-    IThrowableProxy tp = event.getThrowableProxy();
+    boolean isRootException = true;
     while (tp != null) {
       StackTraceElementProxy[] stepArray = tp.getStackTraceElementProxyArray();
       try {
+        handleThrowableFirstLine(sw, tp, stackTracePrefix, isRootException);
+        isRootException = false;
         for (StackTraceElementProxy step : stepArray) {
           StringBuilder sb = new StringBuilder();
           sb.append(stackTracePrefix).append(step);
@@ -91,6 +96,23 @@ public class SyslogAppender extends SyslogAppenderBase<ILoggingEvent> {
     }
   }
 
+  // LOGBACK-411 and  LOGBACK-750
+  private void handleThrowableFirstLine(OutputStream sw, IThrowableProxy tp, String stackTracePrefix, boolean isRootException) throws IOException {
+    StringBuilder sb = new StringBuilder().append(stackTracePrefix);
+
+    if (!isRootException) {
+      sb.append(CoreConstants.CAUSED_BY);
+    }
+    sb.append(tp.getClassName()).append(": ").append(tp.getMessage());
+    sw.write(sb.toString().getBytes());
+    sw.flush();
+  }
+
+  boolean stackTraceHeaderLine(StringBuilder sb, boolean topException) {
+
+    return false;
+  }
+
   public Layout<ILoggingEvent> buildLayout() {
     PatternLayout layout = new PatternLayout();
     layout.getInstanceConverterMap().put("syslogStart",
@@ -102,7 +124,7 @@ public class SyslogAppender extends SyslogAppenderBase<ILoggingEvent> {
     layout.setContext(getContext());
     layout.start();
     return layout;
-   }
+  }
 
   private void setupStackTraceLayout() {
     stackTraceLayout.getInstanceConverterMap().put("syslogStart",
