@@ -1,6 +1,6 @@
 /**
  * Logback: the reliable, generic, fast and flexible logging framework.
- * Copyright (C) 1999-2009, QOS.ch. All rights reserved.
+ * Copyright (C) 1999-2013, QOS.ch. All rights reserved.
  *
  * This program and the accompanying materials are dual-licensed under
  * either the terms of the Eclipse Public License v1.0 as published by
@@ -33,8 +33,7 @@ public class CopyOnInheritThreadLocal extends
     if (parentValue == null) {
       return null;
     } else {
-      HashMap<String, String> hm = new HashMap<String, String>(parentValue);
-      return hm;
+      return new HashMap<String, String>(parentValue);
     }
   }
 
