@@ -1,6 +1,6 @@
 /**
  * Logback: the reliable, generic, fast and flexible logging framework.
- * Copyright (C) 1999-2011, QOS.ch. All rights reserved.
+ * Copyright (C) 1999-2013, QOS.ch. All rights reserved.
  *
  * This program and the accompanying materials are dual-licensed under
  * either the terms of the Eclipse Public License v1.0 as published by
@@ -22,8 +22,10 @@ import ch.qos.logback.classic.spi.LoggingEvent;
 import ch.qos.logback.core.CoreConstants;
 import ch.qos.logback.core.boolex.EvaluationException;
 import ch.qos.logback.core.status.StatusChecker;
+import ch.qos.logback.core.util.ContextUtil;
 import ch.qos.logback.core.util.StatusPrinter;
 import org.junit.Before;
+import org.junit.Ignore;
 import org.junit.Test;
 import org.slf4j.MDC;
 import org.slf4j.Marker;
@@ -68,6 +70,9 @@ public class GEventEvaluatorTest {
     StatusPrinter.printInCaseOfErrorsOrWarnings(context);
     assertTrue(statusChecker.isErrorFree(0));
 
+    ContextUtil contextUtil = new ContextUtil(context);
+    contextUtil.addGroovyPackages(context.getFrameworkPackages());
+    contextUtil.addFrameworkPackage(context.getFrameworkPackages(), "ch.qos.logback.classic.boolex");
 
     boolean result = gee.evaluate(event);
     assertEquals(expected, result);
@@ -128,14 +133,12 @@ public class GEventEvaluatorTest {
     MDC.clear();
   }
 
-
   @Test
   public void callerData() throws EvaluationException {
     LoggingEvent event = makeEvent("x");
     doEvaluateAndCheck("e.callerData.find{ it.className =~ /junit/ }", event, true);
   }
 
-
   double loop(GEventEvaluator gee) throws EvaluationException {
     long start = System.nanoTime();
     ILoggingEvent event = makeEvent("x");
@@ -155,7 +158,8 @@ public class GEventEvaluatorTest {
   }
 
   @Test
-  public void perfTest() throws EvaluationException {
+  @Ignore
+  public void MANUAL_perfTest() throws EvaluationException {
     gee.setExpression("event.timeStamp < 100 && event.message != 'xx' ");
     gee.start();
 
