@@ -1,6 +1,6 @@
 /**
  * Logback: the reliable, generic, fast and flexible logging framework.
- * Copyright (C) 1999-2011, QOS.ch. All rights reserved.
+ * Copyright (C) 1999-2013, QOS.ch. All rights reserved.
  *
  * This program and the accompanying materials are dual-licensed under
  * either the terms of the Eclipse Public License v1.0 as published by
@@ -13,10 +13,6 @@
  */
 package ch.qos.logback.classic.issue.lbclassic203;
 
-import static org.junit.Assert.assertEquals;
-
-import org.junit.Test;
-
 import ch.qos.logback.classic.ClassicTestConstants;
 import ch.qos.logback.classic.Logger;
 import ch.qos.logback.classic.LoggerContext;
@@ -25,7 +21,9 @@ import ch.qos.logback.classic.joran.JoranConfigurator;
 import ch.qos.logback.core.contention.MultiThreadedHarness;
 import ch.qos.logback.core.contention.RunnableWithCounterAndDone;
 import ch.qos.logback.core.joran.spi.JoranException;
-import ch.qos.logback.core.status.StatusChecker;
+import org.junit.Test;
+
+import static org.junit.Assert.assertEquals;
 
 public class ConcurrentSiftingTest {
   final static int THREAD_COUNT = 5;
@@ -35,7 +33,6 @@ public class ConcurrentSiftingTest {
   LoggerContext loggerContext = new LoggerContext();
   protected Logger logger = loggerContext.getLogger(this.getClass().getName());
   protected Logger root = loggerContext.getLogger(Logger.ROOT_LOGGER_NAME);
-  StatusChecker sc = new StatusChecker(loggerContext);
 
   int totalTestDuration = 50;
   MultiThreadedHarness harness = new MultiThreadedHarness(totalTestDuration);
