@@ -1,6 +1,6 @@
 /**
  * Logback: the reliable, generic, fast and flexible logging framework.
- * Copyright (C) 1999-2011, QOS.ch. All rights reserved.
+ * Copyright (C) 1999-2013, QOS.ch. All rights reserved.
  *
  * This program and the accompanying materials are dual-licensed under
  * either the terms of the Eclipse Public License v1.0 as published by
@@ -80,7 +80,7 @@ public class ConditionalTest {
     ConsoleAppender consoleAppender = (ConsoleAppender) root.getAppender("CON");
     assertNotNull(consoleAppender);
     StatusChecker checker = new StatusChecker(context);
-    assertTrue(checker.isErrorFree(0));
+    checker.assertIsErrorFree();
   }
 
   @SuppressWarnings("rawtypes")
@@ -97,7 +97,7 @@ public class ConditionalTest {
     ConsoleAppender consoleAppender = (ConsoleAppender) root.getAppender("CON");
     assertNull(consoleAppender);
     StatusChecker checker = new StatusChecker(context);
-    assertTrue(checker.isErrorFree(0));
+    checker.assertIsErrorFree();
   }
 
   @SuppressWarnings("rawtypes")
@@ -120,7 +120,7 @@ public class ConditionalTest {
 
     // StatusPrinter.printIfErrorsOccured(context);
     StatusChecker checker = new StatusChecker(context);
-    assertTrue(checker.isErrorFree(0));
+    checker.assertIsErrorFree();
   }
 
   @Test
@@ -131,11 +131,10 @@ public class ConditionalTest {
              + "conditional/conditionalIncludeExistingFile.xml";
      configure(configFileAsStr);
 
-     StatusPrinter.print(context);
      ConsoleAppender consoleAppender = (ConsoleAppender) root.getAppender("CON");
      assertNotNull(consoleAppender);
      StatusChecker checker = new StatusChecker(context);
-     assertTrue(checker.isErrorFree(0));
+    checker.assertIsErrorFree();
    }
   @Test
 
@@ -146,11 +145,10 @@ public class ConditionalTest {
              + "conditional/conditionalIncludeInexistentFile.xml";
      configure(configFileAsStr);
 
-     StatusPrinter.print(context);
      ConsoleAppender consoleAppender = (ConsoleAppender) root.getAppender("CON");
      assertNull(consoleAppender);
      StatusChecker checker = new StatusChecker(context);
-     assertTrue(checker.isErrorFree(0));
+     checker.assertIsErrorFree();
    }
 
 
