@@ -1,6 +1,6 @@
 /**
  * Logback: the reliable, generic, fast and flexible logging framework.
- * Copyright (C) 1999-2011, QOS.ch. All rights reserved.
+ * Copyright (C) 1999-2013, QOS.ch. All rights reserved.
  *
  * This program and the accompanying materials are dual-licensed under
  * either the terms of the Eclipse Public License v1.0 as published by
@@ -19,7 +19,8 @@ import org.junit.runners.Suite.SuiteClasses;
 
 @RunWith(Suite.class)
 @SuiteClasses( { SyslogAppenderTest.class, DilutedSMTPAppenderTest.class,
-    SocketAppenderTest.class, JMSQueueAppenderTest.class, JMSTopicAppenderTest.class,
-        SMTPAppender_GreenTest.class, SMTPAppender_SubethaSMTPTest.class })
+        JMSQueueAppenderTest.class, JMSTopicAppenderTest.class,
+        SMTPAppender_GreenTest.class, SMTPAppender_SubethaSMTPTest.class,
+        SocketReceiverTest.class, SSLSocketReceiverTest.class })
 public class PackageTest {
 }
\ No newline at end of file
