@@ -1,6 +1,6 @@
 /**
  * Logback: the reliable, generic, fast and flexible logging framework.
- * Copyright (C) 1999-2011, QOS.ch. All rights reserved.
+ * Copyright (C) 1999-2013, QOS.ch. All rights reserved.
  *
  * This program and the accompanying materials are dual-licensed under
  * either the terms of the Eclipse Public License v1.0 as published by
@@ -28,10 +28,7 @@ import javax.mail.internet.MimeMessage;
 import javax.mail.internet.MimeMultipart;
 
 import org.dom4j.io.SAXReader;
-import org.junit.After;
-import org.junit.Before;
-import org.junit.Ignore;
-import org.junit.Test;
+import org.junit.*;
 import org.subethamail.smtp.AuthenticationHandler;
 import org.subethamail.smtp.AuthenticationHandlerFactory;
 import org.subethamail.smtp.auth.LoginAuthenticationHandler;
@@ -54,34 +51,51 @@ import ch.qos.logback.core.Layout;
 import ch.qos.logback.core.util.StatusPrinter;
 
 public class SMTPAppender_SubethaSMTPTest {
-
-  int diff = 1024 + new Random().nextInt(30000);
-  Wiser wiser;
-
-  SMTPAppender smtpAppender;
-  LoggerContext loggerContext = new LoggerContext();
-
   static final String TEST_SUBJECT = "test subject";
   static final String HEADER = "HEADER\n";
   static final String FOOTER = "FOOTER\n";
 
+  static int DIFF = 1024 + new Random().nextInt(30000);
+  static Wiser WISER;
+
+  SMTPAppender smtpAppender;
+  LoggerContext loggerContext = new LoggerContext();
+
+  int numberOfOldMessages;
+
+
+  @BeforeClass
+  static public void beforeClass() {
+    WISER = new Wiser();
+    WISER.setPort(DIFF);
+    WISER.start();
+  }
+
+  @AfterClass
+  static public void afterClass() throws Exception {
+    WISER.stop();
+  }
+
   @Before
-  public void setUp() throws Exception { 
-    wiser = new Wiser();
-    wiser.setPort(diff);
-    wiser.start();
-    //StartTLSCommand s;
+  public void setUp() throws Exception {
+    numberOfOldMessages = WISER.getMessages().size();
     buildSMTPAppender();
   }
 
+  @After
+  public void tearDown() {
+    // clear any authentication handler factory
+    MessageListenerAdapter mla = (MessageListenerAdapter) WISER.getServer().getMessageHandlerFactory();
+    mla.setAuthenticationHandlerFactory(null);
+  }
+
   void buildSMTPAppender() throws Exception {
     smtpAppender = new SMTPAppender();
     smtpAppender.setContext(loggerContext);
     smtpAppender.setName("smtp");
     smtpAppender.setFrom("user@host.dom");
     smtpAppender.setSMTPHost("localhost");
-    System.out.println("diff="+diff);
-    smtpAppender.setSMTPPort(diff);
+    smtpAppender.setSMTPPort(DIFF);
     smtpAppender.setSubject(TEST_SUBJECT);
     smtpAppender.addTo("noreply@qos.ch");
   }
@@ -106,10 +120,6 @@ public class SMTPAppender_SubethaSMTPTest {
     return layout;
   }
 
-  @After
-  public void tearDown() throws Exception {
-    wiser.stop();
-  }
 
   private static String getWholeMessage(Part msg) {
     try {
@@ -131,7 +141,7 @@ public class SMTPAppender_SubethaSMTPTest {
     String all = getWholeMessage(msg);
     int i = all.indexOf("\r\n\r\n");
     return all.substring(i + 4, all.length());
-}
+  }
 
   @Test
   public void smoke() throws Exception {
@@ -143,25 +153,27 @@ public class SMTPAppender_SubethaSMTPTest {
     logger.error("en error", new Exception("an exception"));
 
     waitUntilEmailIsSent();
-    System.out.println("*** "+((ThreadPoolExecutor)loggerContext.getExecutorService()).getCompletedTaskCount());
-    List<WiserMessage> wiserMsgList = wiser.getMessages();
-    
+    System.out.println("*** " + ((ThreadPoolExecutor) loggerContext.getExecutorService()).getCompletedTaskCount());
+    List<WiserMessage> wiserMsgList = WISER.getMessages();
+
     assertNotNull(wiserMsgList);
-    assertEquals(1, wiserMsgList.size());
-    WiserMessage wm = wiserMsgList.get(0);
+    assertEquals(numberOfOldMessages+1, wiserMsgList.size());
+    WiserMessage wm = wiserMsgList.get(numberOfOldMessages);
     // http://jira.qos.ch/browse/LBCLASSIC-67
     MimeMessage mm = wm.getMimeMessage();
     assertEquals(TEST_SUBJECT, mm.getSubject());
 
     MimeMultipart mp = (MimeMultipart) mm.getContent();
     String body = getBody(mp.getBodyPart(0));
-    System.out.println("["+body);
+    System.out.println("[" + body);
     assertTrue(body.startsWith(HEADER.trim()));
     assertTrue(body.endsWith(FOOTER.trim()));
   }
 
+
   @Test
   public void html() throws Exception {
+
     smtpAppender.setLayout(buildHTMLLayout(loggerContext));
     smtpAppender.start();
     Logger logger = loggerContext.getLogger("test");
@@ -169,11 +181,12 @@ public class SMTPAppender_SubethaSMTPTest {
     logger.debug("hello");
     logger.error("en error", new Exception("an exception"));
     waitUntilEmailIsSent();
-    List<WiserMessage> wiserMsgList = wiser.getMessages();
-    
+
+    List<WiserMessage> wiserMsgList = WISER.getMessages();
+
     assertNotNull(wiserMsgList);
-    assertEquals(1, wiserMsgList.size());
-    WiserMessage wm = wiserMsgList.get(0);
+    assertEquals(numberOfOldMessages + 1, wiserMsgList.size());
+    WiserMessage wm = wiserMsgList.get(numberOfOldMessages);
     MimeMessage mm = wm.getMimeMessage();
     assertEquals(TEST_SUBJECT, mm.getSubject());
 
@@ -191,7 +204,7 @@ public class SMTPAppender_SubethaSMTPTest {
   /**
    * Checks that even when many events are processed, the output is still
    * conforms to xhtml-strict.dtd.
-   * 
+   *
    * Note that SMTPAppender only keeps only 500 or so (=buffer size) events. So
    * the generated output will be rather short.
    */
@@ -205,11 +218,11 @@ public class SMTPAppender_SubethaSMTPTest {
     }
     logger.error("en error", new Exception("an exception"));
     waitUntilEmailIsSent();
-    List<WiserMessage> wiserMsgList = wiser.getMessages();
-    
+    List<WiserMessage> wiserMsgList = WISER.getMessages();
+
     assertNotNull(wiserMsgList);
-    assertEquals(1, wiserMsgList.size());
-    WiserMessage wm = wiserMsgList.get(0);
+    assertEquals(numberOfOldMessages + 1, wiserMsgList.size());
+    WiserMessage wm = wiserMsgList.get(numberOfOldMessages);
     MimeMessage mm = wm.getMimeMessage();
     assertEquals(TEST_SUBJECT, mm.getSubject());
 
@@ -221,15 +234,15 @@ public class SMTPAppender_SubethaSMTPTest {
     reader.setEntityResolver(new XHTMLEntityResolver());
     reader.read(mp.getBodyPart(0).getInputStream());
   }
-  
+
   @Test
   public void authenticated() throws Exception {
-    MessageListenerAdapter mla = (MessageListenerAdapter)wiser.getServer().getMessageHandlerFactory();
+    MessageListenerAdapter mla = (MessageListenerAdapter) WISER.getServer().getMessageHandlerFactory();
     mla.setAuthenticationHandlerFactory(new TrivialAuthHandlerFactory());
 
     smtpAppender.setUsername("x");
     smtpAppender.setPassword("x");
-    
+
     smtpAppender.setLayout(buildPatternLayout(loggerContext));
     smtpAppender.start();
     Logger logger = loggerContext.getLogger("test");
@@ -237,11 +250,11 @@ public class SMTPAppender_SubethaSMTPTest {
     logger.debug("hello");
     logger.error("en error", new Exception("an exception"));
     waitUntilEmailIsSent();
-    List<WiserMessage> wiserMsgList = wiser.getMessages();
+    List<WiserMessage> wiserMsgList = WISER.getMessages();
 
     assertNotNull(wiserMsgList);
-    assertEquals(1, wiserMsgList.size());
-    WiserMessage wm = wiserMsgList.get(0);
+    assertEquals(numberOfOldMessages + 1, wiserMsgList.size());
+    WiserMessage wm = wiserMsgList.get(numberOfOldMessages);
     // http://jira.qos.ch/browse/LBCLASSIC-67
     MimeMessage mm = wm.getMimeMessage();
     assertEquals(TEST_SUBJECT, mm.getSubject());
@@ -251,19 +264,20 @@ public class SMTPAppender_SubethaSMTPTest {
     assertTrue(body.startsWith(HEADER.trim()));
     assertTrue(body.endsWith(FOOTER.trim()));
   }
-  
+
   @Test
-  @Ignore 
+  @Ignore
   // Unfortunately, there seems to be a problem with SubethaSMTP's implementation
   // of startTLS. The same SMTPAppender code works fine when tested with gmail.
   public void authenticatedSSL() throws Exception {
-    MessageListenerAdapter mla = (MessageListenerAdapter)wiser.getServer().getMessageHandlerFactory();
+    MessageListenerAdapter mla = (MessageListenerAdapter) WISER.getServer().getMessageHandlerFactory();
     mla.setAuthenticationHandlerFactory(new TrivialAuthHandlerFactory());
-    
+
+
     smtpAppender.setSTARTTLS(true);
     smtpAppender.setUsername("xx");
-    smtpAppender.setPassword("xx");    
-  
+    smtpAppender.setPassword("xx");
+
     smtpAppender.setLayout(buildPatternLayout(loggerContext));
     smtpAppender.start();
     Logger logger = loggerContext.getLogger("test");
@@ -272,23 +286,23 @@ public class SMTPAppender_SubethaSMTPTest {
     logger.error("en error", new Exception("an exception"));
 
     waitUntilEmailIsSent();
-    List<WiserMessage> wiserMsgList = wiser.getMessages();
+    List<WiserMessage> wiserMsgList = WISER.getMessages();
 
     assertNotNull(wiserMsgList);
     assertEquals(1, wiserMsgList.size());
   }
-  
+
   @Test
   @Ignore
   public void authenticatedGmailStartTLS() throws Exception {
     smtpAppender.setSMTPHost("smtp.gmail.com");
     smtpAppender.setSMTPPort(587);
-    
+
     smtpAppender.addTo("XXX@gmail.com");
     smtpAppender.setSTARTTLS(true);
     smtpAppender.setUsername("XXX@gmail.com");
-    smtpAppender.setPassword("XXX");    
-  
+    smtpAppender.setPassword("XXX");
+
     smtpAppender.setLayout(buildPatternLayout(loggerContext));
     smtpAppender.start();
     Logger logger = loggerContext.getLogger("authenticatedGmailSTARTTLS");
@@ -298,18 +312,18 @@ public class SMTPAppender_SubethaSMTPTest {
 
     StatusPrinter.print(loggerContext);
   }
-  
+
   @Test
   @Ignore
   public void authenticatedGmail_SSL() throws Exception {
     smtpAppender.setSMTPHost("smtp.gmail.com");
     smtpAppender.setSMTPPort(465);
-    
+
     smtpAppender.addTo("XXX@gmail.com");
     smtpAppender.setSSL(true);
     smtpAppender.setUsername("XXX@gmail.com");
-    smtpAppender.setPassword("XXX");    
-  
+    smtpAppender.setPassword("XXX");
+
     smtpAppender.setLayout(buildPatternLayout(loggerContext));
     smtpAppender.start();
     Logger logger = loggerContext.getLogger("authenticatedGmail_SSL");
@@ -330,20 +344,20 @@ public class SMTPAppender_SubethaSMTPTest {
     logger.debug("hello");
     logger.error("en error", new Exception("an exception"));
     waitUntilEmailIsSent();
-    List<WiserMessage> wiserMsgList = wiser.getMessages();
 
+    List<WiserMessage> wiserMsgList = WISER.getMessages();
     assertNotNull(wiserMsgList);
-    assertEquals(3, wiserMsgList.size());
+    assertEquals(numberOfOldMessages + 3, wiserMsgList.size());
   }
-  
+
   public class TrivialAuthHandlerFactory implements AuthenticationHandlerFactory {
     public AuthenticationHandler create() {
       PluginAuthenticationHandler ret = new PluginAuthenticationHandler();
       UsernamePasswordValidator validator = new UsernamePasswordValidator() {
         public void login(String username, String password)
-            throws LoginFailedException {
-          if(!username.equals(password)) {
-            throw new LoginFailedException("username="+username+", password="+password);
+                throws LoginFailedException {
+          if (!username.equals(password)) {
+            throw new LoginFailedException("username=" + username + ", password=" + password);
           }
         }
       };
