@@ -1,6 +1,6 @@
 /**
  * Logback: the reliable, generic, fast and flexible logging framework.
- * Copyright (C) 1999-2011, QOS.ch. All rights reserved.
+ * Copyright (C) 1999-2013, QOS.ch. All rights reserved.
  *
  * This program and the accompanying materials are dual-licensed under
  * either the terms of the Eclipse Public License v1.0 as published by
@@ -51,7 +51,7 @@ public class SyslogAppenderTest {
   public void tearDown() throws Exception {
   }
 
-  public void setMockServerAndConfigure(int expectedCount)
+  public void setMockServerAndConfigure(int expectedCount, String suffixPattern)
       throws InterruptedException {
     int port = RandomUtil.getRandomServerPort();
 
@@ -64,7 +64,7 @@ public class SyslogAppenderTest {
     sa.setSyslogHost("localhost");
     sa.setFacility("MAIL");
     sa.setPort(port);
-    sa.setSuffixPattern("[%thread] %logger %msg");
+    sa.setSuffixPattern(suffixPattern);
     sa.setStackTracePattern("[%thread] foo "+CoreConstants.TAB);
     sa.start();
     assertTrue(sa.isStarted());
@@ -74,6 +74,11 @@ public class SyslogAppenderTest {
     logger.addAppender(sa);
 
   }
+  
+  public void setMockServerAndConfigure(int expectedCount)
+	      throws InterruptedException {
+	 this.setMockServerAndConfigure(expectedCount, "[%thread] %logger %msg");   
+  }
 
   @Test
   public void basic() throws InterruptedException {
@@ -101,6 +106,32 @@ public class SyslogAppenderTest {
         + logMsg);
 
   }
+  
+  @Test
+  public void suffixPatternWithTag() throws InterruptedException {
+    setMockServerAndConfigure(1, "test/something [%thread] %logger %msg");
+    String logMsg = "hello";
+    logger.debug(logMsg);
+
+    // wait max 2 seconds for mock server to finish. However, it should
+    // much sooner than that.
+    mockServer.join(8000);
+
+    assertTrue(mockServer.isFinished());
+    assertEquals(1, mockServer.getMessageList().size());
+    String msg = mockServer.getMessageList().get(0);
+
+    String threadName = Thread.currentThread().getName();
+
+    String expected = "<"
+        + (SyslogConstants.LOG_MAIL + SyslogConstants.DEBUG_SEVERITY) + ">";
+    assertTrue(msg.startsWith(expected));
+
+    String first = "<\\d{2}>\\w{3} \\d{2} \\d{2}(:\\d{2}){2} [\\w.-]* ";
+    checkRegexMatch(msg, first + "test/something \\[" + threadName + "\\] " + loggerName + " "
+            + logMsg);
+
+  }
 
   @Test
   public void tException() throws InterruptedException {
@@ -136,6 +167,10 @@ public class SyslogAppenderTest {
     checkRegexMatch(msg, regex);
 
     msg = mockServer.getMessageList().get(1);
+    assertTrue(msg.contains(ex.getClass().getName()));
+    assertTrue(msg.contains(ex.getMessage()));
+
+    msg = mockServer.getMessageList().get(2);
     assertTrue(msg.startsWith(expected));
     regex = expectedPrefix + "\\[" + threadName + "\\] " +  "foo "+CoreConstants.TAB + "at ch\\.qos.*";
     checkRegexMatch(msg, regex);
@@ -148,7 +183,7 @@ public class SyslogAppenderTest {
 
   @Test
   public void large() throws InterruptedException {
-    setMockServerAndConfigure(1);
+    setMockServerAndConfigure(2);
     StringBuilder largeBuf = new StringBuilder();
     for (int i = 0; i < 2 * 1024 * 1024; i++) {
       largeBuf.append('a');
@@ -162,15 +197,24 @@ public class SyslogAppenderTest {
     
     mockServer.join(8000);
     assertTrue(mockServer.isFinished());
-    
-    // the first message is wasted
-    assertEquals(1, mockServer.getMessageList().size());
-    String msg = mockServer.getMessageList().get(0);
-    String expected = "<"
+ 
+   // both messages received
+    assertEquals(2, mockServer.getMessageList().size());
+
+   String expected = "<"
         + (SyslogConstants.LOG_MAIL + SyslogConstants.DEBUG_SEVERITY) + ">";
-    assertTrue(msg.startsWith(expected));
     String expectedPrefix = "<\\d{2}>\\w{3} \\d{2} \\d{2}(:\\d{2}){2} [\\w.-]* ";
     String threadName = Thread.currentThread().getName();
+
+    // large message is truncated
+    String largeMsg = mockServer.getMessageList().get(0);
+    assertTrue(largeMsg.startsWith(expected));
+    String largeRegex = expectedPrefix + "\\[" + threadName + "\\] " + loggerName
+        + " " + "a{64000,66000}";
+    checkRegexMatch(largeMsg, largeRegex);
+
+    String msg = mockServer.getMessageList().get(1);
+    assertTrue(msg.startsWith(expected));
     String regex = expectedPrefix + "\\[" + threadName + "\\] " + loggerName
         + " " + logMsg;
     checkRegexMatch(msg, regex);
