@@ -1,6 +1,6 @@
 /**
  * Logback: the reliable, generic, fast and flexible logging framework.
- * Copyright (C) 1999-2011, QOS.ch. All rights reserved.
+ * Copyright (C) 1999-2013, QOS.ch. All rights reserved.
  *
  * This program and the accompanying materials are dual-licensed under
  * either the terms of the Eclipse Public License v1.0 as published by
@@ -27,7 +27,7 @@ public class CallerDataTest  {
     Throwable t = new Throwable();
     StackTraceElement[] steArray = t.getStackTrace();
     
-    StackTraceElement[] cda = CallerData.extract(t, CallerDataTest.class.getName(), 50);
+    StackTraceElement[] cda = CallerData.extract(t, CallerDataTest.class.getName(), 50, null);
     assertNotNull(cda);
     assertTrue(cda.length > 0);
     assertEquals(steArray.length - 1, cda.length);
@@ -40,7 +40,7 @@ public class CallerDataTest  {
    */
   @Test
   public void testDeferredProcessing() {
-    StackTraceElement[] cda = CallerData.extract(new Throwable(), "com.inexistent.foo", 10);
+    StackTraceElement[] cda = CallerData.extract(new Throwable(), "com.inexistent.foo", 10, null);
     assertNotNull(cda);
     assertEquals(0, cda.length);
   }
