@@ -1,6 +1,6 @@
 /**
  * Logback: the reliable, generic, fast and flexible logging framework.
- * Copyright (C) 1999-2011, QOS.ch. All rights reserved.
+ * Copyright (C) 1999-2013, QOS.ch. All rights reserved.
  *
  * This program and the accompanying materials are dual-licensed under
  * either the terms of the Eclipse Public License v1.0 as published by
@@ -14,7 +14,9 @@
 package ch.qos.logback.classic.util;
 
 import ch.qos.logback.classic.Logger;
+import ch.qos.logback.classic.LoggerContext;
 import ch.qos.logback.core.read.ListAppender;
+import ch.qos.logback.core.util.StatusPrinter;
 import org.junit.Test;
 import org.slf4j.LoggerFactory;
 
@@ -25,16 +27,11 @@ import static org.junit.Assert.assertNotNull;
  */
 public class InitializationIntegrationTest {
 
-
-
   @Test
   public void smoke() {
     Logger logger = (Logger) LoggerFactory.getLogger(this.getClass());
     Logger root = (Logger) LoggerFactory.getLogger(Logger.ROOT_LOGGER_NAME);
-    //StatusPrinter.print((LoggerContext)LoggerFactory.getILoggerFactory());
     ListAppender la = (ListAppender) root.getAppender("LIST");
     assertNotNull(la);
   }
-
-
 }
