@@ -1,6 +1,6 @@
 /**
  * Logback: the reliable, generic, fast and flexible logging framework.
- * Copyright (C) 1999-2011, QOS.ch. All rights reserved.
+ * Copyright (C) 1999-2013, QOS.ch. All rights reserved.
  *
  * This program and the accompanying materials are dual-licensed under
  * either the terms of the Eclipse Public License v1.0 as published by
@@ -20,7 +20,7 @@ import org.junit.runners.Suite.SuiteClasses;
 import ch.qos.logback.classic.LoggerPerfTest;
 
 @RunWith(Suite.class)
-@SuiteClasses( { RecursiveInitializationTest.class, LoggerPerfTest.class})
+@SuiteClasses( { RecursiveInitializationTest.class, LoggerPerfTest.class, InitializationOutputTest.class})
 public class PackageTest {
 
 }
\ No newline at end of file
