@@ -1,6 +1,6 @@
 /**
  * Logback: the reliable, generic, fast and flexible logging framework.
- * Copyright (C) 1999-2011, QOS.ch. All rights reserved.
+ * Copyright (C) 1999-2013, QOS.ch. All rights reserved.
  *
  * This program and the accompanying materials are dual-licensed under
  * either the terms of the Eclipse Public License v1.0 as published by
@@ -35,7 +35,7 @@ public class DriverManagerConnectionSource extends ConnectionSourceBase {
     try {
       if (driverClass != null) {
         Class.forName(driverClass);
-        discoverConnnectionProperties();
+        discoverConnectionProperties();
       } else {
         addError("WARNING: No JDBC driver specified for logback DriverManagerConnectionSource.");
       }
