@@ -1,6 +1,6 @@
 /**
  * Logback: the reliable, generic, fast and flexible logging framework.
- * Copyright (C) 1999-2009, QOS.ch. All rights reserved.
+ * Copyright (C) 1999-2013, QOS.ch. All rights reserved.
  *
  * This program and the accompanying materials are dual-licensed under
  * either the terms of the Eclipse Public License v1.0 as published by
@@ -39,16 +39,19 @@ public class IncludeAction extends Action {
   private static final String FILE_ATTR = "file";
   private static final String URL_ATTR = "url";
   private static final String RESOURCE_ATTR = "resource";
+  private static final String OPTIONAL_ATTR = "optional";
 
   private String attributeInUse;
+  private boolean optional;
 
   @Override
   public void begin(InterpretationContext ec, String name, Attributes attributes)
           throws ActionException {
 
-    SaxEventRecorder recorder = new SaxEventRecorder();
+    SaxEventRecorder recorder = new SaxEventRecorder(context);
 
     this.attributeInUse = null;
+    this.optional = OptionHelper.toBoolean(attributes.getValue(OPTIONAL_ATTR), false);
 
     if (!checkAttributes(attributes)) {
       return;
@@ -59,17 +62,18 @@ public class IncludeAction extends Action {
     try {
       if (in != null) {
         parseAndRecord(in, recorder);
+        // remove the <included> tag from the beginning and </included> from the end
+        trimHeadAndTail(recorder);
+
+        // offset = 2, because we need to get past this element as well as the end element
+        ec.getJoranInterpreter().getEventPlayer().addEventsDynamically(recorder.saxEventList, 2);
       }
     } catch (JoranException e) {
       addError("Error while parsing  " + attributeInUse, e);
     } finally {
       close(in);
     }
-    // remove the <included> tag from the beginning and </included> from the end
-    trimHeadAndTail(recorder);
 
-    // offset = 2, because we need to get past this element as well as the end element
-    ec.getJoranInterpreter().addEventsDynamically(recorder.saxEventList, 2);
   }
 
   void close(InputStream in) {
@@ -139,8 +143,10 @@ public class IncludeAction extends Action {
     try {
       return url.openStream();
     } catch (IOException e) {
-      String errMsg = "Failed to open [" + url.toString() + "]";
-      addError(errMsg, e);
+      if (!optional) {
+        String errMsg = "Failed to open [" + url.toString() + "]";
+        addError(errMsg, e);
+      }
       return null;
     }
   }
@@ -197,7 +203,7 @@ public class IncludeAction extends Action {
 
   InputStream getInputStream(InterpretationContext ec, Attributes attributes) {
     URL inputURL = getInputURL(ec, attributes);
-    if(inputURL == null)
+    if (inputURL == null)
       return null;
 
     ConfigurationWatchListUtil.addToWatchList(context, inputURL);
