@@ -1,6 +1,6 @@
 /**
  * Logback: the reliable, generic, fast and flexible logging framework.
- * Copyright (C) 1999-2011, QOS.ch. All rights reserved.
+ * Copyright (C) 1999-2013, QOS.ch. All rights reserved.
  *
  * This program and the accompanying materials are dual-licensed under
  * either the terms of the Eclipse Public License v1.0 as published by
@@ -56,7 +56,6 @@ public class FileAppenderResilienceTest {
     fa.setEncoder(new EchoEncoder<Object>());
     fa.setFile(logfileStr);
     fa.start();
-
   }
 
   @Test
@@ -86,10 +85,12 @@ public class FileAppenderResilienceTest {
     t.join();
 
     double bestCaseSuccessRatio = 1/delayCoefficient;
-    double lossinessFactor = 0.8;
+    // expect to loose at most 35% of the events
+    double lossinessFactor = 0.35;
+    double resilianceFactor = (1-lossinessFactor);
 
     ResilienceUtil
-              .verify(logfileStr, "^hello (\\d{1,5})$", runner.getCounter(), bestCaseSuccessRatio * lossinessFactor);
+              .verify(logfileStr, "^hello (\\d{1,5})$", runner.getCounter(), bestCaseSuccessRatio * resilianceFactor);
   }
 
   private void closeLogFileOnPurpose() throws IOException {
