@@ -1,6 +1,6 @@
 /**
  * Logback: the reliable, generic, fast and flexible logging framework.
- * Copyright (C) 1999-2011, QOS.ch. All rights reserved.
+ * Copyright (C) 1999-2013, QOS.ch. All rights reserved.
  *
  * This program and the accompanying materials are dual-licensed under
  * either the terms of the Eclipse Public License v1.0 as published by
@@ -17,10 +17,10 @@ import org.junit.runner.RunWith;
 import org.junit.runners.Suite;
 
 
-
 @RunWith(Suite.class)
-@Suite.SuiteClasses( { DummyAppenderTest.class, ConsoleAppenderTest.class,
-  FileAppenderTest.class})
-    
+@Suite.SuiteClasses({DummyAppenderTest.class,
+        ConsoleAppenderTest.class,
+        FileAppenderTest.class})
+
 public class PackageTest {
 }
