@@ -1,6 +1,6 @@
 /**
  * Logback: the reliable, generic, fast and flexible logging framework.
- * Copyright (C) 1999-2011, QOS.ch. All rights reserved.
+ * Copyright (C) 1999-2013, QOS.ch. All rights reserved.
  *
  * This program and the accompanying materials are dual-licensed under
  * either the terms of the Eclipse Public License v1.0 as published by
@@ -19,6 +19,7 @@ import static org.junit.Assert.assertTrue;
 
 import java.util.HashMap;
 
+import ch.qos.logback.core.joran.spi.ElementSelector;
 import org.junit.After;
 import org.junit.Before;
 import org.junit.Test;
@@ -28,7 +29,6 @@ import ch.qos.logback.core.ContextBase;
 import ch.qos.logback.core.joran.SimpleConfigurator;
 import ch.qos.logback.core.joran.spi.InterpretationContext;
 import ch.qos.logback.core.joran.spi.JoranException;
-import ch.qos.logback.core.joran.spi.Pattern;
 import ch.qos.logback.core.status.Status;
 import ch.qos.logback.core.status.StatusChecker;
 import ch.qos.logback.core.util.CoreTestConstants;
@@ -47,7 +47,7 @@ public class DefinePropertyActionTest {
   private static final String NOCLASS_XML = "noclass.xml";
   private static final String BADCLASS_XML = "badclass.xml";
 
-  SimpleConfigurator sc;
+  SimpleConfigurator simpleConfigurator;
   Context context = new ContextBase();
   DefinePropertyAction definerAction;
   InterpretationContext ic;
@@ -56,10 +56,10 @@ public class DefinePropertyActionTest {
   @Before
   public void setUp() throws Exception {
 
-    HashMap<Pattern, Action> rulesMap = new HashMap<Pattern, Action>();
-    rulesMap.put(new Pattern("define"), new DefinePropertyAction());
-    sc = new SimpleConfigurator(rulesMap);
-    sc.setContext(context);
+    HashMap<ElementSelector, Action> rulesMap = new HashMap<ElementSelector, Action>();
+    rulesMap.put(new ElementSelector("define"), new DefinePropertyAction());
+    simpleConfigurator = new SimpleConfigurator(rulesMap);
+    simpleConfigurator.setContext(context);
   }
 
   @After
@@ -69,40 +69,40 @@ public class DefinePropertyActionTest {
 
   @Test
   public void good() throws JoranException {
-    sc.doConfigure(DEFINE_INPUT_DIR + GOOD_XML);
-    // get from context
-    String inContextFoo = context.getProperty("foo");
+    simpleConfigurator.doConfigure(DEFINE_INPUT_DIR + GOOD_XML);
+    InterpretationContext ic = simpleConfigurator.getInterpreter().getInterpretationContext();
+    String inContextFoo = ic.getProperty("foo");
     assertEquals("monster", inContextFoo);
   }
 
   @Test
   public void noName() throws JoranException {
-    sc.doConfigure(DEFINE_INPUT_DIR + NONAME_XML);
+    simpleConfigurator.doConfigure(DEFINE_INPUT_DIR + NONAME_XML);
     // get from context
     String inContextFoo = context.getProperty("foo");
     assertNull(inContextFoo);
     // check context errors
-    assertTrue(checker.containsMatch(Status.ERROR,
-        "Missing property name for property definer. Near \\[define\\] line 1"));
+    checker.assertContainsMatch(Status.ERROR,
+        "Missing property name for property definer. Near \\[define\\] line 1");
   }
 
   @Test
   public void noClass() throws JoranException {
-    sc.doConfigure(DEFINE_INPUT_DIR + NOCLASS_XML);
+    simpleConfigurator.doConfigure(DEFINE_INPUT_DIR + NOCLASS_XML);
     String inContextFoo = context.getProperty("foo");
     assertNull(inContextFoo);
-    assertTrue(checker.containsMatch(Status.ERROR,
-        "Missing class name for property definer. Near \\[define\\] line 1"));
+    checker.assertContainsMatch(Status.ERROR,
+        "Missing class name for property definer. Near \\[define\\] line 1");
   }
 
   @Test
   public void testBadClass() throws JoranException {
-    sc.doConfigure(DEFINE_INPUT_DIR + BADCLASS_XML);
+    simpleConfigurator.doConfigure(DEFINE_INPUT_DIR + BADCLASS_XML);
     // get from context
     String inContextFoo = context.getProperty("foo");
     assertNull(inContextFoo);
     // check context errors
-    checker.containsMatch(Status.ERROR, "Could not create an PropertyDefiner of type");
+    checker.assertContainsMatch(Status.ERROR, "Could not create an PropertyDefiner of type");
   }
 
 }
