@@ -1,6 +1,6 @@
 /**
  * Logback: the reliable, generic, fast and flexible logging framework.
- * Copyright (C) 1999-2011, QOS.ch. All rights reserved.
+ * Copyright (C) 1999-2013, QOS.ch. All rights reserved.
  *
  * This program and the accompanying materials are dual-licensed under
  * either the terms of the Eclipse Public License v1.0 as published by
@@ -38,7 +38,7 @@ import ch.qos.logback.core.ContextBase;
 import ch.qos.logback.core.joran.TrivialConfigurator;
 import ch.qos.logback.core.joran.action.ext.StackAction;
 import ch.qos.logback.core.joran.spi.JoranException;
-import ch.qos.logback.core.joran.spi.Pattern;
+import ch.qos.logback.core.joran.spi.ElementSelector;
 import ch.qos.logback.core.status.Status;
 import ch.qos.logback.core.status.StatusChecker;
 import ch.qos.logback.core.testUtil.RandomUtil;
@@ -60,6 +60,8 @@ public class IncludeActionTest {
 
   static final String TOP_BY_FILE = INCLUSION_DIR_PREFIX + "topByFile.xml";
 
+  static final String TOP_OPTIONAL = INCLUSION_DIR_PREFIX + "topOptional.xml";
+
   static final String INTERMEDIARY_FILE = INCLUSION_DIR_PREFIX
       + "intermediaryByFile.xml";
 
@@ -89,10 +91,10 @@ public class IncludeActionTest {
   @Before
   public void setUp() throws Exception {
     FileTestUtil.makeTestOutputDir();
-    HashMap<Pattern, Action> rulesMap = new HashMap<Pattern, Action>();
-    rulesMap.put(new Pattern("x"), new NOPAction());
-    rulesMap.put(new Pattern("x/include"), new IncludeAction());
-    rulesMap.put(new Pattern("x/stack"), stackAction);
+    HashMap<ElementSelector, Action> rulesMap = new HashMap<ElementSelector, Action>();
+    rulesMap.put(new ElementSelector("x"), new NOPAction());
+    rulesMap.put(new ElementSelector("x/include"), new IncludeAction());
+    rulesMap.put(new ElementSelector("x/stack"), stackAction);
 
     tc = new TrivialConfigurator(rulesMap);
     tc.setContext(context);
@@ -115,6 +117,13 @@ public class IncludeActionTest {
     verifyConfig(new String[] { "IA", "IB" });
   }
 
+  @Test
+  public void optionalFile() throws JoranException {
+    tc.doConfigure(TOP_OPTIONAL);
+    verifyConfig(new String[] { "IA", "IB" });
+    StatusPrinter.print(context);
+  }
+
   @Test
   public void basicResource() throws JoranException {
     System.setProperty(INCLUDE_KEY, INCLUDED_AS_RESOURCE);
