@@ -1,6 +1,6 @@
 /**
  * Logback: the reliable, generic, fast and flexible logging framework.
- * Copyright (C) 1999-2011, QOS.ch. All rights reserved.
+ * Copyright (C) 1999-2013, QOS.ch. All rights reserved.
  *
  * This program and the accompanying materials are dual-licensed under
  * either the terms of the Eclipse Public License v1.0 as published by
@@ -107,7 +107,7 @@ public class PropertyActionTest  {
   
   @Test
   public void testLoadFileWithPrerequisiteSubsitution() {
-    context.putProperty("STEM", CoreTestConstants.TEST_DIR_PREFIX + "input/joran");
+    context.putProperty("STEM", CoreTestConstants.TEST_SRC_PREFIX + "input/joran");
     atts.setValue("file", "${STEM}/propertyActionTest.properties");
     propertyAction.begin(ec, null, atts);
     assertEquals("tata", ec.getProperty("v1"));
@@ -116,7 +116,7 @@ public class PropertyActionTest  {
 
   @Test
   public void testLoadFile() {
-    atts.setValue("file", CoreTestConstants.TEST_DIR_PREFIX + "input/joran/propertyActionTest.properties");
+    atts.setValue("file", CoreTestConstants.TEST_SRC_PREFIX + "input/joran/propertyActionTest.properties");
     propertyAction.begin(ec, null, atts);
     assertEquals("tata", ec.getProperty("v1"));
     assertEquals("toto", ec.getProperty("v2"));
