@@ -1,6 +1,6 @@
 /**
  * Logback: the reliable, generic, fast and flexible logging framework.
- * Copyright (C) 1999-2011, QOS.ch. All rights reserved.
+ * Copyright (C) 1999-2013, QOS.ch. All rights reserved.
  *
  * This program and the accompanying materials are dual-licensed under
  * either the terms of the Eclipse Public License v1.0 as published by
@@ -47,9 +47,8 @@ public class SaxEventRecorderTest {
   }
 
   public List<SaxEvent> doTest(String filename) throws Exception {
-    SaxEventRecorder recorder = new SaxEventRecorder();
-    recorder.setContext(context);
-    FileInputStream fis = new FileInputStream(CoreTestConstants.TEST_DIR_PREFIX
+    SaxEventRecorder recorder = new SaxEventRecorder(context);
+    FileInputStream fis = new FileInputStream(CoreTestConstants.TEST_SRC_PREFIX
         + "input/joran/"+ filename);
     recorder.recordEvents(fis);
     return  recorder.getSaxEventList();
