@@ -1,6 +1,6 @@
 /**
  * Logback: the reliable, generic, fast and flexible logging framework.
- * Copyright (C) 1999-2011, QOS.ch. All rights reserved.
+ * Copyright (C) 1999-2013, QOS.ch. All rights reserved.
  *
  * This program and the accompanying materials are dual-licensed under
  * either the terms of the Eclipse Public License v1.0 as published by
@@ -20,12 +20,12 @@ import static org.junit.Assert.assertTrue;
 import java.util.HashMap;
 import java.util.List;
 
+import ch.qos.logback.core.joran.spi.ElementSelector;
 import org.junit.Test;
 
 import ch.qos.logback.core.joran.SimpleConfigurator;
 import ch.qos.logback.core.joran.action.Action;
 import ch.qos.logback.core.joran.action.NOPAction;
-import ch.qos.logback.core.joran.spi.Pattern;
 import ch.qos.logback.core.util.CoreTestConstants;
 import ch.qos.logback.core.util.StatusPrinter;
 
@@ -39,16 +39,16 @@ public class FruitConfigurationTest  {
   public List<FruitShell> doFirstPart(String filename) throws Exception {
 
     try {
-      HashMap<Pattern, Action> rulesMap = new HashMap<Pattern, Action>();
-      rulesMap.put(new Pattern("group/fruitShell"), new FruitShellAction());
-      rulesMap.put(new Pattern("group/fruitShell/fruit"),
+      HashMap<ElementSelector, Action> rulesMap = new HashMap<ElementSelector, Action>();
+      rulesMap.put(new ElementSelector("group/fruitShell"), new FruitShellAction());
+      rulesMap.put(new ElementSelector("group/fruitShell/fruit"),
           new FruitFactoryAction());
-      rulesMap.put(new Pattern("group/fruitShell/fruit/*"), new NOPAction());
+      rulesMap.put(new ElementSelector("group/fruitShell/fruit/*"), new NOPAction());
       SimpleConfigurator simpleConfigurator = new SimpleConfigurator(rulesMap);
 
       simpleConfigurator.setContext(fruitContext);
 
-      simpleConfigurator.doConfigure(CoreTestConstants.TEST_DIR_PREFIX + "input/joran/replay/"
+      simpleConfigurator.doConfigure(CoreTestConstants.TEST_SRC_PREFIX + "input/joran/replay/"
           + filename);
 
       return fruitContext.getFruitShellList();
