@@ -1,6 +1,6 @@
 /**
  * Logback: the reliable, generic, fast and flexible logging framework.
- * Copyright (C) 1999-2011, QOS.ch. All rights reserved.
+ * Copyright (C) 1999-2013, QOS.ch. All rights reserved.
  *
  * This program and the accompanying materials are dual-licensed under
  * either the terms of the Eclipse Public License v1.0 as published by
@@ -41,14 +41,14 @@ public class DefaultNestedComponentRegistryTest {
   public void smoke() {
     String propertyName = "window";
     registry.add(House.class, propertyName, Window.class);
-    Class result = registry.findDefaultComponentType(House.class, propertyName);
+    Class<?> result = registry.findDefaultComponentType(House.class, propertyName);
     assertEquals(Window.class, result);
   }
 
   @Test
   public void absent() {
     registry.add(House.class, "a", Window.class);
-    Class result = registry.findDefaultComponentType(House.class, "other");
+    Class<?> result = registry.findDefaultComponentType(House.class, "other");
     assertNull(result);
   }
 }
