@@ -1,6 +1,6 @@
 /**
  * Logback: the reliable, generic, fast and flexible logging framework.
- * Copyright (C) 1999-2011, QOS.ch. All rights reserved.
+ * Copyright (C) 1999-2013, QOS.ch. All rights reserved.
  *
  * This program and the accompanying materials are dual-licensed under
  * either the terms of the Eclipse Public License v1.0 as published by
@@ -18,7 +18,7 @@ import org.junit.runners.Suite;
 import org.junit.runners.Suite.SuiteClasses;
 
 @RunWith(Suite.class)
-@SuiteClasses( { PatternTest.class, SimpleRuleStoreTest.class,
+@SuiteClasses( { ElementSelectorTest.class, SimpleRuleStoreTest.class,
     NoAutoStartUtilTest.class,  ConfigurationWatchListTest.class,
     DefaultNestedComponentRegistryTest.class, CaseCombinatorTest.class })
 public class PackageTest {
