@@ -1,6 +1,6 @@
 /**
  * Logback: the reliable, generic, fast and flexible logging framework.
- * Copyright (C) 1999-2011, QOS.ch. All rights reserved.
+ * Copyright (C) 1999-2013, QOS.ch. All rights reserved.
  *
  * This program and the accompanying materials are dual-licensed under
  * either the terms of the Eclipse Public License v1.0 as published by
@@ -84,8 +84,8 @@ abstract public class AbstractPatternLayoutBaseTest<E> {
     String s = plb.doLayout(getEventObject());
     assertEquals("", s);
     StatusChecker checker = new StatusChecker(context.getStatusManager());
-    StatusPrinter.print(context);
-    assertTrue(checker.containsMatch("Empty or null pattern."));
+    //StatusPrinter.print(context);
+    checker.assertContainsMatch("Empty or null pattern.");
   }
 
   @Test
@@ -99,8 +99,8 @@ abstract public class AbstractPatternLayoutBaseTest<E> {
     String s = plb.doLayout(getEventObject());
     assertEquals("", s);
     StatusChecker checker = new StatusChecker(context.getStatusManager());
-    StatusPrinter.print(context);
-    assertTrue(checker.containsMatch("Empty or null pattern."));
+    //StatusPrinter.print(context);
+    checker.assertContainsMatch("Empty or null pattern.");
   }
 
 }
