@@ -1,6 +1,6 @@
 /**
  * Logback: the reliable, generic, fast and flexible logging framework.
- * Copyright (C) 1999-2011, QOS.ch. All rights reserved.
+ * Copyright (C) 1999-2013, QOS.ch. All rights reserved.
  *
  * This program and the accompanying materials are dual-licensed under
  * either the terms of the Eclipse Public License v1.0 as published by
@@ -22,6 +22,7 @@ import java.util.List;
 
 import ch.qos.logback.core.Context;
 import ch.qos.logback.core.ContextBase;
+import ch.qos.logback.core.spi.ScanException;
 import ch.qos.logback.core.status.StatusChecker;
 import org.junit.Test;
 
@@ -283,8 +284,8 @@ public class ParserTest {
       assertEquals("Expecting RIGHT_PARENTHESIS token but got null", ise.getMessage());
     }
     StatusChecker sc = new StatusChecker(context);
-    assertTrue(sc.containsMatch("Expecting RIGHT_PARENTHESIS"));
-    assertTrue(sc.containsMatch("See also " + Parser.MISSING_RIGHT_PARENTHESIS));
+    sc.assertContainsMatch("Expecting RIGHT_PARENTHESIS");
+    sc.assertContainsMatch("See also " + Parser.MISSING_RIGHT_PARENTHESIS);
   }
 
 }
\ No newline at end of file
