@@ -1,6 +1,6 @@
 /**
  * Logback: the reliable, generic, fast and flexible logging framework.
- * Copyright (C) 1999-2011, QOS.ch. All rights reserved.
+ * Copyright (C) 1999-2013, QOS.ch. All rights reserved.
  *
  * This program and the accompanying materials are dual-licensed under
  * either the terms of the Eclipse Public License v1.0 as published by
@@ -46,14 +46,13 @@ public class RecoveryCoordinatorTest {
       rc.setCurrentTime(now+offset);
      
       if(rc.isTooSoon()) {
-        //System.out.println("is     too soon at "+(offset));
+        System.out.println("isTooSoon successful at "+(offset));
         tooSoonCount++;
       } else {
         //System.out.println("is NOT too soon at "+(offset));
     }
       offset *= 2;
     }
-    assertEquals(7, tooSoonCount);
-    
+    assertEquals(8, tooSoonCount);
   }
 }
