@@ -1,6 +1,6 @@
 /**
  * Logback: the reliable, generic, fast and flexible logging framework.
- * Copyright (C) 1999-2011, QOS.ch. All rights reserved.
+ * Copyright (C) 1999-2013, QOS.ch. All rights reserved.
  *
  * This program and the accompanying materials are dual-licensed under
  * either the terms of the Eclipse Public License v1.0 as published by
@@ -43,9 +43,9 @@ public class CompressTest {
     // Copy source files
     // Delete output files
     {
-      File source = new File(CoreTestConstants.TEST_DIR_PREFIX
+      File source = new File(CoreTestConstants.TEST_SRC_PREFIX
           + "input/compress1.copy");
-      File dest = new File(CoreTestConstants.TEST_DIR_PREFIX
+      File dest = new File(CoreTestConstants.TEST_SRC_PREFIX
           + "input/compress1.txt");
 
       copy(source, dest);
@@ -55,9 +55,9 @@ public class CompressTest {
       target.delete();
     }
     {
-      File source = new File(CoreTestConstants.TEST_DIR_PREFIX
+      File source = new File(CoreTestConstants.TEST_SRC_PREFIX
           + "input/compress2.copy");
-      File dest = new File(CoreTestConstants.TEST_DIR_PREFIX
+      File dest = new File(CoreTestConstants.TEST_SRC_PREFIX
           + "input/compress2.txt");
       copy(source, dest);
       File target = new File(CoreTestConstants.OUTPUT_DIR_PREFIX
@@ -66,9 +66,9 @@ public class CompressTest {
       target.delete();
     }
     {
-      File source = new File(CoreTestConstants.TEST_DIR_PREFIX
+      File source = new File(CoreTestConstants.TEST_SRC_PREFIX
           + "input/compress3.copy");
-      File dest = new File(CoreTestConstants.TEST_DIR_PREFIX
+      File dest = new File(CoreTestConstants.TEST_SRC_PREFIX
           + "input/compress3.txt");
       copy(source, dest);
       File target = new File(CoreTestConstants.OUTPUT_DIR_PREFIX
@@ -82,14 +82,14 @@ public class CompressTest {
   public void test1() throws Exception {
     Compressor compressor = new Compressor(CompressionMode.GZ);
     compressor.setContext(context);
-    compressor.compress(CoreTestConstants.TEST_DIR_PREFIX
+    compressor.compress(CoreTestConstants.TEST_SRC_PREFIX
         + "input/compress1.txt", CoreTestConstants.OUTPUT_DIR_PREFIX
         + "compress1.txt.gz", null);
 
     StatusChecker checker = new StatusChecker(context);
     assertTrue(checker.isErrorFree(0));
     assertTrue(Compare.gzCompare(CoreTestConstants.OUTPUT_DIR_PREFIX
-        + "compress1.txt.gz", CoreTestConstants.TEST_DIR_PREFIX
+        + "compress1.txt.gz", CoreTestConstants.TEST_SRC_PREFIX
         + "witness/compress1.txt.gz"));
   }
 
@@ -97,7 +97,7 @@ public class CompressTest {
   public void test2() throws Exception {
     Compressor compressor = new Compressor(CompressionMode.GZ);
     compressor.setContext(context);
-    compressor.compress(CoreTestConstants.TEST_DIR_PREFIX
+    compressor.compress(CoreTestConstants.TEST_SRC_PREFIX
         + "input/compress2.txt", CoreTestConstants.OUTPUT_DIR_PREFIX
         + "compress2.txt", null);
 
@@ -105,7 +105,7 @@ public class CompressTest {
     assertTrue(checker.isErrorFree(0));
 
     assertTrue(Compare.gzCompare(CoreTestConstants.OUTPUT_DIR_PREFIX
-        + "compress2.txt.gz", CoreTestConstants.TEST_DIR_PREFIX
+        + "compress2.txt.gz", CoreTestConstants.TEST_SRC_PREFIX
         + "witness/compress2.txt.gz"));
   }
 
@@ -113,7 +113,7 @@ public class CompressTest {
   public void test3() throws Exception {
     Compressor compressor = new Compressor(CompressionMode.ZIP);
     compressor.setContext(context);
-    compressor.compress(CoreTestConstants.TEST_DIR_PREFIX
+    compressor.compress(CoreTestConstants.TEST_SRC_PREFIX
         + "input/compress3.txt", CoreTestConstants.OUTPUT_DIR_PREFIX
         + "compress3.txt", "compress3.txt");
     StatusChecker checker = new StatusChecker(context);
@@ -121,7 +121,7 @@ public class CompressTest {
 
     // we don't know how to compare .zip files
     // assertTrue(Compare.compare(CoreTestConstants.OUTPUT_DIR_PREFIX
-    // + "compress3.txt.zip", CoreTestConstants.TEST_DIR_PREFIX
+    // + "compress3.txt.zip", CoreTestConstants.TEST_SRC_PREFIX
     // + "witness/compress3.txt.zip"));
   }
 
