@@ -1,6 +1,6 @@
 /**
  * Logback: the reliable, generic, fast and flexible logging framework.
- * Copyright (C) 1999-2011, QOS.ch. All rights reserved.
+ * Copyright (C) 1999-2013, QOS.ch. All rights reserved.
  *
  * This program and the accompanying materials are dual-licensed under
  * either the terms of the Eclipse Public License v1.0 as published by
@@ -28,7 +28,7 @@ import java.io.PrintStream;
 public class TeeOutputStream extends OutputStream {
 
   final PrintStream targetPS;
-  final ByteArrayOutputStream baos = new ByteArrayOutputStream();
+  public final ByteArrayOutputStream baos = new ByteArrayOutputStream();
 
   public TeeOutputStream(PrintStream targetPS) {
     // allow for null arguments
@@ -38,7 +38,7 @@ public class TeeOutputStream extends OutputStream {
   public void write(int b) throws IOException {
     baos.write(b);
     if(targetPS != null) {
-    targetPS.write(b);
+      targetPS.write(b);
     }
   }
 
