@@ -1,6 +1,6 @@
 /**
  * Logback: the reliable, generic, fast and flexible logging framework.
- * Copyright (C) 1999-2011, QOS.ch. All rights reserved.
+ * Copyright (C) 1999-2013, QOS.ch. All rights reserved.
  *
  * This program and the accompanying materials are dual-licensed under
  * either the terms of the Eclipse Public License v1.0 as published by
@@ -19,8 +19,9 @@ import java.util.Map;
 import ch.qos.logback.core.joran.GenericConfigurator;
 import ch.qos.logback.core.joran.action.Action;
 import ch.qos.logback.core.joran.action.ImplicitAction;
+import ch.qos.logback.core.joran.spi.ElementPath;
 import ch.qos.logback.core.joran.spi.Interpreter;
-import ch.qos.logback.core.joran.spi.Pattern;
+import ch.qos.logback.core.joran.spi.ElementSelector;
 import ch.qos.logback.core.joran.spi.RuleStore;
 
 /**
@@ -31,23 +32,23 @@ import ch.qos.logback.core.joran.spi.RuleStore;
  */
 public class SimpleConfigurator extends GenericConfigurator {
 
-  final Map<Pattern, Action> ruleMap;
+  final Map<ElementSelector, Action> ruleMap;
   final List<ImplicitAction> iaList;
 
-  public SimpleConfigurator(Map<Pattern, Action> ruleMap) {
+  public SimpleConfigurator(Map<ElementSelector, Action> ruleMap) {
     this(ruleMap, null);
   }
 
-  public SimpleConfigurator(Map<Pattern, Action> ruleMap, List<ImplicitAction> iaList) {
+  public SimpleConfigurator(Map<ElementSelector, Action> ruleMap, List<ImplicitAction> iaList) {
     this.ruleMap = ruleMap;
     this.iaList = iaList;
   }
 
   @Override
   protected void addInstanceRules(RuleStore rs) {
-    for (Pattern pattern : ruleMap.keySet()) {
-      Action action = ruleMap.get(pattern);
-      rs.addRule(pattern, action);
+    for (ElementSelector elementSelector : ruleMap.keySet()) {
+      Action action = ruleMap.get(elementSelector);
+      rs.addRule(elementSelector, action);
     }
   }
 
@@ -60,5 +61,4 @@ public class SimpleConfigurator extends GenericConfigurator {
       interpreter.addImplicitAction(ia);
     }
   }
-
 }
