@@ -1,6 +1,6 @@
 /**
  * Logback: the reliable, generic, fast and flexible logging framework.
- * Copyright (C) 1999-2011, QOS.ch. All rights reserved.
+ * Copyright (C) 1999-2013, QOS.ch. All rights reserved.
  *
  * This program and the accompanying materials are dual-licensed under
  * either the terms of the Eclipse Public License v1.0 as published by
@@ -29,7 +29,7 @@ import ch.qos.logback.core.util.OptionHelper;
  * @author Ceki G&uuml;lc&uuml;
  */
 public class LiteralAction extends Action {
-  public static String VALUE_ATR = "value";
+  public static final String VALUE_ATR = "value";
 
   public void begin(InterpretationContext ic, String name, Attributes attributes) {
     String valueStr = attributes.getValue(VALUE_ATR);
