@@ -1,6 +1,6 @@
 /**
  * Logback: the reliable, generic, fast and flexible logging framework.
- * Copyright (C) 1999-2011, QOS.ch. All rights reserved.
+ * Copyright (C) 1999-2013, QOS.ch. All rights reserved.
  *
  * This program and the accompanying materials are dual-licensed under
  * either the terms of the Eclipse Public License v1.0 as published by
@@ -13,11 +13,11 @@
  */
 package chapters.onJoran.implicit;
 
+import ch.qos.logback.core.joran.spi.ElementPath;
 import org.xml.sax.Attributes;
 
 import ch.qos.logback.core.joran.action.ImplicitAction;
 import ch.qos.logback.core.joran.spi.InterpretationContext;
-import ch.qos.logback.core.joran.spi.Pattern;
 
 /**
  * 
@@ -28,7 +28,7 @@ import ch.qos.logback.core.joran.spi.Pattern;
  */
 public class PrintMeImplicitAction extends ImplicitAction {
 
-  public boolean isApplicable(Pattern pattern, Attributes attributes,
+  public boolean isApplicable(ElementPath elementPath, Attributes attributes,
       InterpretationContext ec) {
     String printmeStr = attributes.getValue("printme");
 
