@@ -3,11 +3,13 @@ document.write('<table class="footer" border="0">')
 
 document.write('<tr>')
 
-document.write('<td valign="top">Copyright &copy; 2012  <a href="http://www.qos.ch/">QOS.ch</a></td>')
+document.write('<td valign="top">Copyright &copy; 2013  <a href="http://www.qos.ch/">QOS.ch</a></td>')
 
-document.write('  <td rowspan="2">')
-document.write('    <script type="text/javascript" src="http://www.ohloh.net/p/13616/widgets/project_users.js"></script>')
-document.write('  </td>')
+document.write('  <td rowspan="2">');
+document.write('    <a href="http://twitter.com/qos_ch">');
+document.write('      <img alt="Follow @qos_ch" src="http://www.slf4j.org/images/follow_us.png" />');
+document.write('    </a>');
+document.write('  </td>');
 
 
 document.write('</tr>')
